# Normalization

RMSNorm (Root Mean Square Layer Normalization) kernels with optional residual fusion.

## Functions

::: rotalabs_accel.kernels.normalization.rmsnorm

::: rotalabs_accel.kernels.normalization.rmsnorm_torch

::: rotalabs_accel.kernels.normalization.rmsnorm_residual_fused

## Classes

::: rotalabs_accel.kernels.normalization.TritonRMSNorm
